package mandelbrot;

/**
 * Sequential implementation of the Mandelbrot set computation. (Concrete class
 * in the Template Method pattern)
 * 
 * @author ahoefer
 * 
 */
public class SequentialMandelbrot extends AbstractMandelbrot {

	/**
	 * The created algorithm will compute a Mandelbrot set with the given width
	 * and height.
	 * 
	 * @param width
	 *            the width of the Mandelbrot
	 * @param height
	 *            the height of the Mandelbrot
	 */
	public SequentialMandelbrot(int width, int height) {
		super(width, height);
	}

	/**
	 * Computes the Mandelbrot set sequentially.
	 * 
	 * @return the Mandelbrot
	 */
	protected int[][] compute() {
		int[][] result = new int[width][height];
		double cReal;
		double cImag;
		for (int x = 0; x < width; x++) {
			for (int y = 0; y < height; y++) {
				cReal = translateReal(x);
				cImag = translateImag(y);
				result[x][y] = computeMandelbrotPoint(cReal, cImag);
			}
		}
		return result;
	}
}
